# Sid Meier's Civilization 4
# Copyright Firaxis Games 2007
# AgricultureEvents
# Agriculture Mod By Orion Veteran
# Modular python project to eliminate or reduce merging tasks
from CvPythonExtensions import *
import CvUtil
import CvDebugTools


# globals
gc = CyGlobalContext()


class AgricultureEvents:
	def __init__(self, eventMgr):
# ###############################################################################
#		Important!!!!															#
#		Each function added from CvEventManager.py must be initialized here 	#
# ###############################################################################
		self.__LOG_IMPROVEMENT =0
		self.eventMgr = eventMgr
		
		eventMgr.addEventHandler("improvementBuilt", self.onImprovementBuilt)
	
	def onImprovementBuilt(self, argsList):
		# Agriculture Mod
		# Purpose: Places a agricultural bonus on plot upon worker
		# completion of an improvement (Corn, Rice or Wheat)
		'Improvement Built'
		iImprovement, iX, iY = argsList
		iPlayerID = gc.getPlayer(CyGame().getActivePlayer()).getID()			
		player = gc.getPlayer(iPlayerID)	
		
		if (iImprovement == gc.getInfoTypeForString('IMPROVEMENT_CORN')) :
			pPlot = CyMap().plot(iX, iY)
			pPlot.setImprovementType(-1)
			pPlot.setBonusType(gc.getInfoTypeForString("BONUS_CORN"))			
			
			if (player.isAlive() and player.isHuman()):
				CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'A CORN Field was Planted!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/general/happy_person.dds',ColorTypes(8),iX,iY,False,False)

		if (iImprovement == gc.getInfoTypeForString('IMPROVEMENT_RICE')) :
			pPlot = CyMap().plot(iX, iY)
			pPlot.setImprovementType(0)
			pPlot.setBonusType(gc.getInfoTypeForString("BONUS_RICE"))
			
			if (player.isAlive() and player.isHuman()):
				CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'A RICE Field was Planted!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/general/happy_person.dds',ColorTypes(8),iX,iY,False,False)

		if (iImprovement == gc.getInfoTypeForString('IMPROVEMENT_WHEAT')) :
			pPlot = CyMap().plot(iX, iY)
			pPlot.setImprovementType(0)
			pPlot.setBonusType(gc.getInfoTypeForString("BONUS_WHEAT"))
			
			if (player.isAlive() and player.isHuman()):
				CyInterface().addMessage(CyGame().getActivePlayer(),True,25,'A WHEAT Field was Planted!','AS2D_DISCOVERBONUS',1,'Art/Interface/Buttons/general/happy_person.dds',ColorTypes(8),iX,iY,False,False)
		
		if (not self.__LOG_IMPROVEMENT):
			return
		CvUtil.pyPrint('Improvement %s was built at %d, %d'
			%(PyInfo.ImprovementInfo(iImprovement).getDescription(), iX, iY))
# End Agriculture Mod
		
		
	